==> seedsui-react-5.8.86.tgz: package/lib/Cascader/Main/ListItem.js <==
var _excluded = ["optionProps", "list", "value", "onSelect"];
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }
function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }
import React, { Fragment, forwardRef } from 'react';

// 内库使用
import Notice from "./../../Notice";
import IndexBar from "./../../IndexBar";

// 测试使用
// import { Notice, IndexBar } from 'seedsui-react'

var ListItem = /*#__PURE__*/forwardRef(function (_ref, ref) {
  var optionProps = _ref.optionProps,
    list = _ref.list,
    value = _ref.value,
    onSelect = _ref.onSelect,
    props = _objectWithoutProperties(_ref, _excluded);
  // 显示分栏
  var indexs = {};
  return /*#__PURE__*/React.createElement("div", _extends({}, props, {
    className: "picker-main".concat(props !== null && props !== void 0 && props.className ? ' ' + props.className : ''),
    ref: ref
  }), typeof list === 'string' && /*#__PURE__*/React.createElement(Notice, {
    caption: list
  }), Array.isArray(list) && list.map(function (item, index) {
    // 字母分栏
    var anchorBar = null;
    if (item.anchor && !indexs[item.anchor]) {
      indexs[item.anchor] = true;
      anchorBar = /*#__PURE__*/React.createElement(IndexBar.Anchor, {
        name: item.anchor
      }, /*#__PURE__*/React.createElement("p", {
        className: "indexbar-list-header"
      }, item.anchor));
    }
    return /*#__PURE__*/React.createElement(Fragment, {
      key: item.id
    }, anchorBar, /*#__PURE__*/React.createElement("div", _extends({}, optionProps, {
      className: "cascader-option".concat(optionProps.className ? ' ' + optionProps.className : '').concat(value !== null && value !== void 0 && value.some(function (selected) {
        return selected.id === item.id;
      }) ? ' active' : ''),
      onClick: function onClick(e) {
        e.stopPropagation();
        onSelect(item);
      }
    }), /*#__PURE__*/React.createElement("p", {
      className: "cascader-option-caption"
    }, item.name), /*#__PURE__*/React.createElement("i", {
      className: "cascader-option-icon"
    })));
  }));
});
export default ListItem;

==> seedsui-react-5.8.90.tgz: package/lib/Cascader/Main/ListItem.js <==
var _excluded = ["optionProps", "list", "value", "onSelect"];
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }
function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }
import React, { Fragment, forwardRef } from 'react';

// 内库使用
import locale from "../../locale";
import Notice from "./../../Notice";
import IndexBar from "./../../IndexBar";

// 测试使用
// import { locale, Notice, IndexBar } from 'seedsui-react'

var ListItem = /*#__PURE__*/forwardRef(function (_ref, ref) {
  var optionProps = _ref.optionProps,
    list = _ref.list,
    value = _ref.value,
    onSelect = _ref.onSelect,
    props = _objectWithoutProperties(_ref, _excluded);
  // 显示分栏
  var indexs = {};
  if (Array.isArray(list) && !list.length) {
    // eslint-disable-next-line
    list = locale('暂无数据', 'SeedsUI_no_data');
  }
  return /*#__PURE__*/React.createElement("div", _extends({}, props, {
    className: "picker-main".concat(props !== null && props !== void 0 && props.className ? ' ' + props.className : ''),
    ref: ref
  }), typeof list === 'string' && /*#__PURE__*/React.createElement(Notice, {
    caption: list
  }), Array.isArray(list) && list.map(function (item, index) {
    // 字母分栏
    var anchorBar = null;
    if (item.anchor && !indexs[item.anchor]) {
      indexs[item.anchor] = true;
      anchorBar = /*#__PURE__*/React.createElement(IndexBar.Anchor, {
        name: item.anchor
      }, /*#__PURE__*/React.createElement("p", {
        className: "indexbar-list-header"
      }, item.anchor));
    }
    return /*#__PURE__*/React.createElement(Fragment, {
      key: item.id
    }, anchorBar, /*#__PURE__*/React.createElement("div", _extends({}, optionProps, {
      className: "cascader-option".concat(optionProps.className ? ' ' + optionProps.className : '').concat(value !== null && value !== void 0 && value.some(function (selected) {
        return selected.id === item.id;
      }) ? ' active' : ''),
      onClick: function onClick(e) {
        e.stopPropagation();
        onSelect(item);
      }
    }), /*#__PURE__*/React.createElement("p", {
      className: "cascader-option-caption"
    }, item.name), /*#__PURE__*/React.createElement("i", {
      className: "cascader-option-icon"
    })));
  }));
});
export default ListItem;
